# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.dagster_dagster_log_get_response import DagsterDagsterLogGetResponse

class TestDagsterDagsterLogGetResponse(unittest.TestCase):
    """DagsterDagsterLogGetResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DagsterDagsterLogGetResponse:
        """Test DagsterDagsterLogGetResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DagsterDagsterLogGetResponse`
        """
        model = DagsterDagsterLogGetResponse()
        if include_optional:
            return DagsterDagsterLogGetResponse(
                data = [
                    neurograph.v1.models.dagster/dagster_info.dagster.DagsterInfo(
                        id = 'dag_1234', 
                        job = 'initialize_personas_job', 
                        optional = 'some string, json, or whatever you want.', 
                        run = 'a8763df8-eec2-4856-8bf2-588cb49aa8b2', 
                        ts_created = 56, )
                    ],
                error = ''
            )
        else:
            return DagsterDagsterLogGetResponse(
        )
        """

    def testDagsterDagsterLogGetResponse(self):
        """Test DagsterDagsterLogGetResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.db_knowledge_product import DbKnowledgeProduct

class TestDbKnowledgeProduct(unittest.TestCase):
    """DbKnowledgeProduct unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DbKnowledgeProduct:
        """Test DbKnowledgeProduct
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DbKnowledgeProduct`
        """
        model = DbKnowledgeProduct()
        if include_optional:
            return DbKnowledgeProduct(
                client_id = '',
                entity_id = '',
                handle = '',
                overview = '',
                product_hash = '',
                product_id = neurograph.v1.models.pgtype/int8.pgtype.Int8(
                    int64 = 56, 
                    valid = True, ),
                summary = '',
                title = '',
                type = ''
            )
        else:
            return DbKnowledgeProduct(
        )
        """

    def testDbKnowledgeProduct(self):
        """Test DbKnowledgeProduct"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

if __import__("typing").TYPE_CHECKING:
    # import apis into api package
    from neurograph.v1.api.authentication_api import AuthenticationApi
    from neurograph.v1.api.client_api import ClientApi
    from neurograph.v1.api.client_metadata_api import ClientMetadataApi
    from neurograph.v1.api.dagster_api import DagsterApi
    from neurograph.v1.api.knowledge_api import KnowledgeApi
    from neurograph.v1.api.knowledge_extract_api import KnowledgeExtractApi
    from neurograph.v1.api.lookup_api import LookupApi
    from neurograph.v1.api.organization_api import OrganizationApi
    from neurograph.v1.api.organization_metadata_api import OrganizationMetadataApi
    from neurograph.v1.api.persona_api import PersonaApi
    from neurograph.v1.api.system_api import SystemApi
    from neurograph.v1.api.workbench_api import WorkbenchApi
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            """# import apis into api package
from neurograph.v1.api.authentication_api import AuthenticationApi
from neurograph.v1.api.client_api import ClientApi
from neurograph.v1.api.client_metadata_api import ClientMetadataApi
from neurograph.v1.api.dagster_api import DagsterApi
from neurograph.v1.api.knowledge_api import KnowledgeApi
from neurograph.v1.api.knowledge_extract_api import KnowledgeExtractApi
from neurograph.v1.api.lookup_api import LookupApi
from neurograph.v1.api.organization_api import OrganizationApi
from neurograph.v1.api.organization_metadata_api import OrganizationMetadataApi
from neurograph.v1.api.persona_api import PersonaApi
from neurograph.v1.api.system_api import SystemApi
from neurograph.v1.api.workbench_api import WorkbenchApi

""",
            name=__name__,
            doc=__doc__,
        )
    )
